@@ -55,7 +55,7 @@ isEndOfMib = lambda x: not cmdgen.getNextVarBinds(x)[1]
 @asyncio.coroutine
 def getCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
-    """Creates a generator to perform SNMP GET query.
+    r"""Creates a generator to perform SNMP GET query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP GET request is send (:RFC:`1905#section-4.2.1`).
@@ -162,7 +162,7 @@ def getCmd(snmpEngine, authData, transportTarget, contextData,
 @asyncio.coroutine
 def setCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
-    """Creates a generator to perform SNMP SET query.
+    r"""Creates a generator to perform SNMP SET query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP SET request is send (:RFC:`1905#section-4.2.5`).
@@ -269,7 +269,7 @@ def setCmd(snmpEngine, authData, transportTarget, contextData,
 @asyncio.coroutine
 def nextCmd(snmpEngine, authData, transportTarget, contextData,
             *varBinds, **options):
-    """Creates a generator to perform SNMP GETNEXT query.
+    r"""Creates a generator to perform SNMP GETNEXT query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP GETNEXT request is send (:RFC:`1905#section-4.2.2`).
@@ -382,7 +382,7 @@ def nextCmd(snmpEngine, authData, transportTarget, contextData,
 @asyncio.coroutine
 def bulkCmd(snmpEngine, authData, transportTarget, contextData,
             nonRepeaters, maxRepetitions, *varBinds, **options):
-    """Creates a generator to perform SNMP GETBULK query.
+    r"""Creates a generator to perform SNMP GETBULK query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP GETBULK request is send (:RFC:`1905#section-4.2.3`).
